#!/usr/bin/env python

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sos.plugintools
import sys
import os
import glob

class ovm3(sos.plugintools.PluginBase):
    def setup(self): 
	for vm in glob.glob('/OVS/Repositories/*/.ovsrepo'):
                self.collectExtOutput("cat "+vm, suggest_filename=vm)
        for filel in glob.glob("/var/log/messages*"):
                self.addCopySpec(filel)
        for filel in glob.glob("/var/run/ovs-agent/*.lock*"):
                self.addCopySpec(filel)
        self.addCopySpec("/var/log/ovs-agent.log")	
        self.collectExtOutput("cat /root/.bash_history",suggest_filename="bash_history")	
	self.collectExtOutput("/bin/mount | egrep -e 'automount|pid.*nfs' 2>&1", suggest_filename="auto_nfs_check")
	self.collectExtOutput("service o2cb status",suggest_filename="o2cb.status")
        self.collectExtOutput("service ocfs2 status", suggest_filename="ocfs2.status")
        self.collectExtOutput("service ntpd status", suggest_filename="ntpd.status")
	self.collectExtOutput("xm list", suggest_filename="xm.list")
        self.collectExtOutput("xm dmesg", suggest_filename="xm.dmesg")
        self.collectExtOutput("/usr/sbin/xenpm get-cpuidle-states 2>&1", suggest_filename="xenpm.get-cpuidle-states")
        self.collectExtOutput("/usr/sbin/xenpm get-cpufreq-states", suggest_filename="xenpm.get-cpufreq-states")
        self.collectExtOutput("/usr/sbin/xenpm get-cpuidle-states | grep total | uniq 2>&1", suggest_filename="get_cpuidle_states_uniq")
        self.collectExtOutput("/usr/sbin/xenpm get-cpufreq-para", suggest_filename="xenpm.get-cpufreq-para")
        self.collectExtOutput("xm sched-credit", suggest_filename="xm.sched-credit")
        self.collectExtOutput("xenstore-ls", suggest_filename="xenstore-ls")
        self.collectExtOutput("service xend status", suggest_filename="xend.status")
        self.collectExtOutput("dominfo -c -f", suggest_filename="dominfo-c-f")
        self.collectExtOutput("dom0memcontroller --dumpMemInfo", suggest_filename="dom0memcontroller--dumpMemInfo")
	self.collectExtOutput("for i in cat /OVS/Repositories/*/VirtualMachines/*/vm.cfg; do echo '========Start OVM Guest===============';cat $i;echo '==========EOF===============';done", suggest_filename="vms.configs")
        self.collectExtOutput("rpm -qa | grep -E \(xen\|ovs\|ocfs\) | sort", suggest_filename="rpm_qa_xen_ovs_ocfs")
        self.collectExtOutput("dominfo -c -f", suggest_filename="dominfo-c-f")
	## Virtual Disks
	self.collectExtOutput("/bin/ls -l /OVS/Repositories/*/VirtualDisks", suggest_filename="listvdisks")
	## List file systems
        self.collectExtOutput("/bin/ls -l -R /poolfsmnt", suggest_filename="ls-l-R_poolfsmnt")
        self.collectExtOutput("/bin/ls -l -R /nfsmnt", suggest_filename="ls-l-R_nfsmnt")
	self.collectExtOutput("/bin/ls -l -R /dlm", suggest_filename="ls-l-R-dlm")
	## XEN network information
        self.collectExtOutput("brctl show", suggest_filename="brctl.show")
        self.collectExtOutput("brctl show | egrep  '[[:digit:]]{1,3}\.[[:digit:]]{1,3}\.[[:digit:]]{1,3}\.[[:digit:]]{1,3}' | awk '{print $1}' | xargs -l brctl showmacs", suggest_filename="brctl.showmacs")
        self.collectExtOutput("ip -s -s -s link show", suggest_filename="ip-s-s-s-link-show")
        self.collectExtOutput("ip address show", suggest_filename="ip-address-show")
	## Misc data
        self.collectExtOutput("ps -elfy", suggest_filename="ps-elfy")
        self.collectExtOutput("rpm -qa --queryformat '%{installtime} %{name}-%{version}-%{release} %{installtime:date}\n'", suggest_filename="rpm_qa_installtime")
        self.collectExtOutput("dmesg -T", suggest_filename="dmesg_timestamped")
        self.collectExtOutput("ls -l /sys/kernel/config/cluster/*/node/*/*;cat /sys/kernel/config/cluster/*/node/*/*", suggest_filename="ocfs2_cluster_information")
        self.collectExtOutput("lsof")
        self.collectExtOutput("/sbin/ip route show", suggest_filename="ip_route_show")
	## ovs-agent-db
	self.collectExtOutput("/usr/sbin/ovs-agent-db dump_db server 2>&1", suggest_filename="dump_db_server")
	self.collectExtOutput("/usr/sbin/ovs-agent-db dump_db aproc 2>&1", suggest_filename="dump_db_aproc")
	self.collectExtOutput("/usr/sbin/ovs-agent-db dump_db repository 2>&1", suggest_filename="dump_db_repository")
	self.collectExtOutput("/usr/sbin/ovs-agent-db -c dump_db server_pool 2>&1",suggest_filename="dump_db_serverpool")
	self.collectExtOutput("/usr/sbin/ovs-agent-db -c dump_db server_pool_servers  2>&1",suggest_filename="dump_db_server_pool_servers")
	self.collectExtOutput("/usr/sbin/ovs-agent-db -c dump_db monitored_vms  2>&1",suggest_filename="dump_db_monitored_vms")
	## NTP Information
        self.collectExtOutput("ntpq -pn", suggest_filename="ntpq_-pn")
        self.collectExtOutput("pgrep ntpd", suggest_filename="pgrep_ntpd")
        self.collectExtOutput("netstat -tulpn | grep 123", suggest_filename="netstat_-tulpn_grep_123")
        self.collectExtOutput("date", suggest_filename="date")
        self.collectExtOutput("grep -i ntp /var/log/messages", suggest_filename="ntp_messages")
        self.addCopySpec("/etc/ntp.conf")
	## cat /proc/net/bonding/bondN
	for bond in glob.glob('/proc/net/bonding/bond*'):
       		self.collectExtOutput("/bin/cat "+bond, suggest_filename="proc_net_"+bond)
        self.collectExtOutput("multipath -ll", suggest_filename="multipath-ll")
        self.collectExtOutput("for i in $(seq 0 9); do echo '---- eth$i ----'; ethtool -i eth$i; done",suggest_filename="ethtool")
        # MySQL information
        self.collectExtOutput("rpm -qa |grep -i mysql",suggest_filename="rpm_qa_mysql")
        self.collectExtOutput("ls -lath /u01/app/oracle/mysql/data",suggest_filename="ls_mysql_data")
        self.collectExtOutput("cat /u01/app/oracle/mysql/data/my.cnf",suggest_filename="my.cnf")
        self.collectExtOutput("cat /u01/app/oracle/mysq /data/mysqld.err",suggest_filename="mysqld.err")
        self.collectExtOutput("ps -ef|grep -i mysql",suggest_filename="ps_mysql")
        self.collectExtOutput("df -Ph /u01 | column -t",suggest_filename="u01_size")
	# Get OVM files
	self.collectExtOutput("cat /u01/app/oracle/ovm-manager-3/.config", suggest_filename="ovm-manager_3_config")
        self.collectExtOutput("cat /etc/ovs-config", suggest_filename="ovsconfig")
        self.collectExtOutput("cat /etc/ovs-info", suggest_filename="ovsinfo")
        self.collectExtOutput("cat /etc/ovs-release", suggest_filename="ovsrelease")
        self.collectExtOutput("cat /etc/monitor/config.yml", suggest_filename="config-yml")
        # 
        self.addCopySpec("/root/anaconda-ks.cfg")
        if os.path.exists("/var/log/xsigo"):
            for xsigof in glob.glob("/var/log/xsigo/xsadmdsh.lo*"):
                self.addCopySpec(xsigof)
            for ovmw in glob.glob("ovmwatch.lo*"):
                self.addCopySpec(ovmw)
            for osc in glob.glob("osc.lo*"):
                self.addCopySpec(osc)
            for ovmc in glob.glob("/var/log/ovm-consoled.lo*"):
                self.addCopySpec(ovmc)
            for brcm in glob.glob("/var/log/brcm-iscsi.lo*"):
                self.addCopySpec(brcm)
            self.collectExtOutput("lsmod  | grep xsv", suggest_filename="xsigo_kernel_modules")
        return
